## Installation

Mapviewer requires `npm install leaflet d3 d3-scale-chromatic g1`.

      // leaflet is used internally by mapviewer
      <link rel="stylesheet" href="ui/leaflet/dist/leaflet.css">
      <script src="ui/leaflet/dist/leaflet.js"></script>

      <script src="ui/d3/build/d3.js"></script>
      // d3-scale-chromatic is not required if d3 is v5
      <script src="ui/d3-scale-chromatic/dist/d3-scale-chromatic.min.js"></script>

      // load mapviewer via g1
      <script src="ui/g1/dist/mapviewer.min.js"></script>